
// Hello World with printf() from the device
//
// nvcc -arch=sm_35 --compiler-options -Wall helloworld.cu -o helloworld
//
// GZ, Feb 2013


#include <stdio.h>

__global__
void printFromGPU( void )
{
	printf( "hello world!\n" );
}


// General CUDA error handler
// Prints error message, if something went wrong
void handleCUDAerror( void )
{
	cudaError_t err = cudaGetLastError();
	if ( err == cudaSuccess )
		return;

	printf("CUDA error message: %s\n", cudaGetErrorString( err ) );

	int devID;
    cudaGetDevice( &devID );
    cudaDeviceProp props;
    cudaGetDeviceProperties( &props, devID );
    printf("CUDA device %d: \"%s\" with compute capability %d.%d\n",
           devID, props.name, props.major, props.minor);
}


int main( void )
{
	printf( "Hello World!\n");

	printFromGPU<<<1,16>>>();
	handleCUDAerror();

	cudaDeviceSynchronize();		// very important! otherwise, we might not see the printf's from the device!
	handleCUDAerror();

	cudaDeviceReset();
	return 0;
}

